# verb-conjugator
verb-conjugator is a commandline tool to help users practice / learn to conjugate french and spanish verbs

### Features
Users can:
1. View the conjugations for a selected verb
2. Practice (via a quiz) the different conjugations for a selected verb
3. Practice randomly selected verb conjugations from a list of common verbs for each language in the indicative mood

For features 1 and 2 users can select the mood (indicative, subjunctive etc) as well as the tense (present, imperfect, future etc)

### How to run verb-conjugator
```
$ pip install verb-conjugator
$ conjugator
```

### Usage
```
Select an option:
1 - Display verb conjugation
2 - Single verb quiz
3 - Common verbs quiz
4 - Exit
```

### License
MIT

### Credits
This application uses the [verbecc](https://github.com/bretttolbert/verbecc) python library and was developed as part of the [Python Developer Mindset (PDM)](https://pybit.es/catalogue/the-pdm-program/) program.
